@@ -376,11 +376,13 @@ class VideoProcessor:
                     names = r.names
 
                     if self.is_obb_style(r):
-                        xywhr = r.obb.xywhr.cpu().numpy()
-                        cls = r.obb.cls.cpu().numpy()
+                        xyxy = r.obb.xyxy.cpu().numpy()
+                        conf = r.obb.conf.cpu().numpy()
+                        cls  = r.obb.cls.cpu().numpy()
+
                         boxes_list = [
-                            [*b[:4], float(b[4]), int(c)]
-                            for b, c in zip(xywhr, cls)
+                            [float(x1), float(y1), float(x2), float(y2), float(cf), int(c)]
+                            for (x1, y1, x2, y2), cf, c in zip(xyxy, conf, cls)
                         ]
                     else:
                         xyxy = r.boxes.xyxy.cpu().numpy()
