@@ -4,6 +4,7 @@ import math
 from pathlib import Path
 from datetime import datetime, timedelta, timezone
 from collections import defaultdict
+from shapely.geometry import Polygon
 
 # --- Import class lists + canonical config path ---
 from .classes_config import FOCUS_CLASSES, CONTEXT_CLASSES
@@ -187,17 +188,17 @@ class Counter:
 
         return saved
 
-# ---------- INTERACTIONS ----------
+#   ----- INTERACTIONS -----
 class Interactions:
     def __init__(self, out_folder=None, config=None, start_time=None, is_obb=False):
         self.out_folder = Path(out_folder) if out_folder else None
         self.config = config or MeasurementConfig()
         self.start_time = start_time
-        self.is_obb = is_obb     # <<< NEW!
+        self.is_obb = is_obb
 
-        self.active = {}     # active interactions
-        self.records = []    # completed interactions
-        self.ref_time = None # reference system timestamp
+        self.active = {}
+        self.records = []
+        self.ref_time = None
 
     def _normalize(self, dt):
         return dt if dt.tzinfo else dt.replace(tzinfo=timezone.utc)
@@ -209,20 +210,60 @@ class Interactions:
         delta = (self._normalize(ts) - self._normalize(self.ref_time)).total_seconds()
         return self.start_time + timedelta(seconds=delta)
 
-    @staticmethod
-    def _overlap(a, b, threshold):
-        """Compute IoU-style overlap."""
-        ax1, ay1, ax2, ay2 = a[0]-a[2]/2, a[1]-a[3]/2, a[0]+a[2]/2, a[1]+a[3]/2
-        bx1, by1, bx2, by2 = b[0]-b[2]/2, b[1]-b[3]/2, b[0]+b[2]/2, b[1]+b[3]/2
+    #   ----- ROTATED OBB POLYGON BUILDER -----
+    def _obb_to_polygon(self, box):
+        """
+        Convert xyxy OBB-aligned bounding box to a polygon.
+        NOTE: xyxy from r.obb.xyxy is the bounding rectangle in the frame.
+        For true rotation, UltraLytics currently does not expose the rotated quad,
+        so we use the bounding rectangle as a polygon.
+        """
+        x1, y1, x2, y2 = box[:4]
+        return [(x1, y1), (x2, y1), (x2, y2), (x1, y2)]
+
+    #   ----- ROTATED IoU (POLYGON) -----
+    def _iou_polygon(self, boxA, boxB):
+        polyA = Polygon(self._obb_to_polygon(boxA))
+        polyB = Polygon(self._obb_to_polygon(boxB))
+
+        if not polyA.is_valid or not polyB.is_valid:
+            return 0.0
+
+        inter = polyA.intersection(polyB).area
+        if inter <= 0:
+            return 0.0
+
+        union = polyA.area + polyB.area - inter
+        if union <= 0:
+            return 0.0
+
+        return inter / union
+
+    #   ----- AXIS-ALIGNED IoU (AABB) -----
+    def _iou_aabb(self, a, b):
+        ax1, ay1, ax2, ay2 = a[:4]
+        bx1, by1, bx2, by2 = b[:4]
 
         iw = max(0, min(ax2, bx2) - max(ax1, bx1))
         ih = max(0, min(ay2, by2) - max(ay1, by1))
         if iw == 0 or ih == 0:
-            return False
-        inter = iw * ih
-        union = a[2]*a[3] + b[2]*b[3] - inter
-        return inter / union > threshold
+            return 0.0
 
+        inter = iw * ih
+        union = (ax2 - ax1)*(ay2 - ay1) + (bx2 - bx1)*(by2 - by1) - inter
+        if union <= 0:
+            return 0.0
+
+        return inter / union
+
+    #   ----- UNIVERSAL OVERLAP CHECK -----
+    def _overlap(self, a, b, threshold):
+        if self.is_obb:
+            return self._iou_polygon(a, b) > threshold
+        else:
+            return self._iou_aabb(a, b) > threshold
+
+    #   ----- MAIN INTERACTION ENGINE -----
     def process_frame(self, boxes, names, ts):
         if not self.ref_time:
             self.ref_time = ts
@@ -236,17 +277,20 @@ class Interactions:
 
         if CONTEXT_CLASSES:
             for b in birds:
-                bname = names.get(b[5])
+                name_b = names.get(b[5])
                 for o in objs:
-                    oname = names.get(o[5])
+                    name_o = names.get(o[5])
+
                     if b is o:
                         continue
+
                     if self._overlap(b, o, self.config.overlap_threshold):
-                        pair = (bname, oname)
+                        pair = (name_b, name_o)
                         active_now.add(pair)
                         self._activate(pair, video_ts)
+
         else:
-            # bird-bird interactions
+            # Bird-to-bird interactions
             for i, b1 in enumerate(birds):
                 for j, b2 in enumerate(birds):
                     if j <= i:
@@ -261,14 +305,15 @@ class Interactions:
 
         self._finalize_inactive(active_now, video_ts)
 
+    #   ----- ACTIVATE INTERACTION -----
     def _activate(self, pair, ts):
         if pair not in self.active:
             self.active[pair] = {"start": ts, "last": ts}
         else:
             self.active[pair]["last"] = ts
 
+    #   ----- FINALIZE INACTIVE INTERACTIONS -----
     def _finalize_inactive(self, active_now, ts):
-        """Finish interactions which have timed out."""
         ended = []
         for pair, info in self.active.items():
             if pair not in active_now and (ts - info["last"]).total_seconds() >= self.config.interaction_timeout_sec:
@@ -277,20 +322,21 @@ class Interactions:
         for p in ended:
             del self.active[p]
 
+    #   ----- FINALIZE ALL -----
     def finalize(self):
-        """Force-finish all active interactions at end of video."""
         for pair, info in self.active.items():
             self._record(pair, info["start"], info["last"])
         self.active.clear()
         return self.records
 
+    #   ----- RECORD INTERACTION -----
     def _record(self, pair, start, end):
         dur = round((end - start).total_seconds(), 2)
         if dur <= 0:
             return
 
         if CONTEXT_CLASSES:
-            entry = {
+            row = {
                 "TIME0": start.strftime("%H:%M:%S"),
                 "TIME1": end.strftime("%H:%M:%S"),
                 "FOCUS": pair[0],
@@ -298,7 +344,7 @@ class Interactions:
                 "DURATION": dur,
             }
         else:
-            entry = {
+            row = {
                 "TIME0": start.strftime("%H:%M:%S"),
                 "TIME1": end.strftime("%H:%M:%S"),
                 "CLASS1": pair[0],
@@ -306,8 +352,9 @@ class Interactions:
                 "DURATION": dur,
             }
 
-        self.records.append(entry)
+        self.records.append(row)
 
+    #   ----- SAVE RESULTS -----
     def save_results(self):
         if not self.records or not self.out_folder:
             return None
@@ -320,6 +367,7 @@ class Interactions:
         else:
             headers = ["TIME0", "TIME1", "CLASS1", "CLASS2", "DURATION"]
 
+        import csv
         with open(out_file, "w", newline="") as f:
             w = csv.DictWriter(f, fieldnames=headers)
             w.writeheader()
