@@ -297,9 +297,10 @@ def get_args():
     data_root = BASE_DIR / "data"
     data_root.mkdir(exist_ok=True)
 
-    # Ensure Label Studio root exists for users to drop projects into
+    # Ensure Label Studio root exists
     LS_ROOT.mkdir(exist_ok=True)
 
+    # ------ USER SUPPLIED DATASET DIRECTLY ------
     if args.dataset:
         dataset_folder = data_root / args.dataset
         if not dataset_folder.exists():
@@ -311,44 +312,53 @@ def get_args():
             print(f"[ERROR] data.yaml not found in dataset folder: {DATA_YAML}")
             sys.exit(1)
 
-    else:
-        ls_projects = _find_labelstudio_projects(LS_ROOT)
+    # ------ USER EXPLICITLY REQUESTED LABEL STUDIO PROJECT ------
+    elif args.labelstudio is not None:
 
-        if ls_projects:
-            newest = sorted(ls_projects, key=lambda x: x.stat().st_mtime, reverse=True)[0]
-            print(f"[DATA] Found Label Studio project: {newest}")
-            dataset_folder, DATA_YAML = process_labelstudio_project(
-                newest,
-                data_root,
-                dataset_name=args.final_name  
-            )
-        else:
-            all_datasets = [d for d in data_root.iterdir() if d.is_dir()]
-            if len(all_datasets) == 0:
-                print("[DATA] No datasets yet. Checking Label Studio folder...")
-                ls_projects = _find_labelstudio_projects(LS_ROOT)
-
-                if ls_projects:
-                    newest = sorted(ls_projects, key=lambda x: x.stat().st_mtime, reverse=True)[0]
-                    print(f"[DATA] Processing Label Studio project → {newest}")
-                    dataset_folder, DATA_YAML = process_labelstudio_project(
-                        newest, data_root, dataset_name=args.final_name
-                    )
-                else:
-                    print("[ERROR] No datasets exist and no Label Studio projects were found.")
-                    sys.exit(1)
-
-            elif len(all_datasets) == 1:
-                dataset_folder = all_datasets[0]
-                DATA_YAML = dataset_folder / "data.yaml"
-                print(f"[DATA] Auto-selected dataset: {dataset_folder.name}")
-
-            else:
-                print("[ERROR] Multiple datasets detected; specify with --dataset or --data.")
-                print("Available datasets:", [d.name for d in all_datasets])
+        # If user passed -ls with no name → use newest LS project
+        if args.labelstudio is True or args.labelstudio == "":
+            ls_projects = _find_labelstudio_projects(LS_ROOT)
+            if not ls_projects:
+                print("[ERROR] No Label Studio projects found in labelstudio-projects/")
                 sys.exit(1)
 
+            newest = sorted(ls_projects, key=lambda x: x.stat().st_mtime, reverse=True)[0]
+            print(f"[DATA] Using newest Label Studio project: {newest}")
+            dataset_folder, DATA_YAML = process_labelstudio_project(
+                newest, data_root, dataset_name=args.final_name
+            )
 
+        # -ls somefolder
+        else:
+            specific = LS_ROOT / args.labelstudio
+            if not specific.exists():
+                print(f"[ERROR] Specified Label Studio project not found: {specific}")
+                sys.exit(1)
+
+            print(f"[DATA] Processing specified Label Studio project: {specific}")
+            dataset_folder, DATA_YAML = process_labelstudio_project(
+                specific, data_root, dataset_name=args.final_name
+            )
+
+    # ------ NO LS REQUEST — USE LOCAL DATASETS ONLY -----
+    else:
+        all_datasets = [d for d in data_root.iterdir() if d.is_dir()]
+
+        if len(all_datasets) == 0:
+            print("[ERROR] No datasets exist. Provide --dataset or use --labelstudio to process a project.")
+            sys.exit(1)
+
+        elif len(all_datasets) == 1:
+            dataset_folder = all_datasets[0]
+            DATA_YAML = dataset_folder / "data.yaml"
+            print(f"[DATA] Auto-selected dataset: {dataset_folder.name}")
+
+        else:
+            print("[ERROR] Multiple datasets detected; specify with --dataset or --data.")
+            print("Available datasets:", [d.name for d in all_datasets])
+            sys.exit(1)
+
+    # Final validation
     if not DATA_YAML.exists():
         print(f"[ERROR] data.yaml not found in: {DATA_YAML}")
         sys.exit(1)
